summaryrefslogtreecommitdiff
path: root/sys/net/if_bridge.h
diff options
context:
space:
mode:
authorJason Wright <jason@cvs.openbsd.org>1999-03-01 04:44:45 +0000
committerJason Wright <jason@cvs.openbsd.org>1999-03-01 04:44:45 +0000
commit1211d39b07c91e33d52e5bf82d3fcda41715f51b (patch)
tree4140b15b412266fa14868707cb59c732622c166b /sys/net/if_bridge.h
parent4a6d5c512e998e2de70b33261943e87d2dcc3780 (diff)
completely (almost) revamped ioctl's:
o new ioctls for getting/setting cache size (default == 100) o changed SIOCBRDGRT -> SIOCBRDGRTS o changed SIOCBRDGIDX -> SIOCBRDGIFS
Diffstat (limited to 'sys/net/if_bridge.h')
-rw-r--r--sys/net/if_bridge.h55
1 files changed, 43 insertions, 12 deletions
diff --git a/sys/net/if_bridge.h b/sys/net/if_bridge.h
index d127c091604..ec873697c1a 100644
--- a/sys/net/if_bridge.h
+++ b/sys/net/if_bridge.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_bridge.h,v 1.1 1999/02/26 17:01:32 jason Exp $ */
+/* $OpenBSD: if_bridge.h,v 1.2 1999/03/01 04:44:44 jason Exp $ */
/*
* Copyright (c) 1999 Jason L. Wright (jason@thought.net)
@@ -32,23 +32,54 @@
*/
/*
- * Bridge control request: (add/delete/iterate) member interfaces.
+ * Bridge control request: add/delete member interfaces.
*/
struct ifbreq {
- char ifbname[IFNAMSIZ]; /* bridge ifs name */
- char ifsname[IFNAMSIZ]; /* member ifs name */
- u_int32_t index; /* iteration index */
+ char ifbr_name[IFNAMSIZ]; /* bridge ifs name */
+ char ifbr_ifsname[IFNAMSIZ]; /* member ifs name */
+ u_int32_t ifbr_ifsflags; /* memver ifs flags */
};
/*
- * Bridge routing request: iterate known routes.
+ * Interface list structure
*/
-struct ifbrtreq {
- char ifbname[IFNAMSIZ]; /* bridge ifs name */
- u_int32_t index; /* iteration index */
- struct ether_addr dst; /* destination addr */
- char ifsname[IFNAMSIZ]; /* destination ifs */
- u_int16_t age; /* route age */
+struct ifbifconf {
+ char ifbic_name[IFNAMSIZ]; /* bridge ifs name */
+ u_int32_t ifbic_len; /* buffer size */
+ union {
+ caddr_t ifbicu_buf;
+ struct ifbreq *ifbicu_req;
+ } ifbic_ifbicu;
+#define ifbic_buf ifbic_ifbicu.ifbicu_buf
+#define ifbic_req ifbic_ifbicu.ifbicu_req
+};
+
+/*
+ * Bridge address request
+ */
+struct ifbareq {
+ char ifba_name[IFNAMSIZ]; /* destination ifs */
+ u_int32_t ifba_age; /* route age */
+ struct ether_addr ifba_dst; /* destination addr */
+};
+
+struct ifbaconf {
+ char ifbac_name[IFNAMSIZ]; /* bridge ifs name */
+ u_int32_t ifbac_len; /* buffer size */
+ union {
+ caddr_t ifbacu_buf; /* buffer */
+ struct ifbareq *ifbacu_req; /* request pointer */
+ } ifbac_ifbacu;
+#define ifbac_buf ifbac_ifbacu.ifbacu_buf
+#define ifbac_req ifbac_ifbacu.ifbacu_req
+};
+
+/*
+ * Bridge cache size get/set
+ */
+struct ifbcachereq {
+ char ifbc_name[IFNAMSIZ]; /* bridge ifs name */
+ u_int32_t ifbc_size; /* cache size */
};
#ifdef _KERNEL